
if Trimble::MaterialResizer.isDebug?
    load Sketchup.find_support_file('MaterialResizerUI.rb', 'Plugins/MaterialResizer')
else
    Sketchup::load 'MaterialResizer/MaterialResizerUI'
end

module Trimble
module MaterialResizer
class MaterialResizerActions
def MaterialResizerActions.resizeMats(mats, maxSize)
  isMac = Trimble::MaterialResizer.isMac
  tempDir = Trimble::MaterialResizer.tempDir
  exeDir = File.join(File.dirname(__FILE__), 'bin', (isMac ? 'osx' : 'x86'))
  cmdName = File.join(exeDir, (isMac ? "bin/convert" : "convert.exe"))
  if isMac
    File.chmod(0755, cmdName)  # Make sure it's executable before we try to run it
    # Prepend the environment variables we need
    cmdName = 'DYLD_LIBRARY_PATH="' + File.join(exeDir, 'lib') + '" "' + cmdName + '"'
  else
    cmdName = '"' + cmdName + '"'
  end
  tmpFolder = tempDir
  matsResized = 0

  mats.each {|mat| 
    next if mat.texture == nil 
    #puts "#{File.basename(mat.texture.filename)}: #{mat.texture.image_width} x #{mat.texture.image_height} <=> #{mat.texture.width} x #{mat.texture.height}" 
    resizeStr = nil
    if mat.texture.image_width > maxSize
      #puts "Resizing (width is too big)"
      resizeStr = "#{maxSize}x"
      resizeStr = "x#{maxSize}" if mat.texture.image_height > mat.texture.image_width
    elsif mat.texture.image_height > maxSize
      #puts "Resizing (height is too big)"
      resizeStr = "x#{maxSize}"
    end
    next if resizeStr == nil
    
    texName = File.join(tmpFolder, File.basename(mat.texture.filename))
    oldSize = [mat.texture.width, mat.texture.height]
    mat.texture.write(texName)
    cmdLine = cmdName + " \"" + texName + "\" -resize " + resizeStr + " +repage \"" + texName + "\""
    #puts cmdLine
    system(cmdLine)
    mat.texture = texName
    mat.texture.size = oldSize
    File.delete(texName)
    matsResized += 1
  }
  UI.messagebox("Resized #{matsResized} materials")
end

def MaterialResizerActions.printMatSizes()
  Sketchup.active_model.materials.each {|mat|
  next if mat.texture == nil 
  puts "#{File.basename(mat.texture.filename)}: #{mat.texture.image_width} x #{mat.texture.image_height} <=> #{mat.texture.width} x #{mat.texture.height}" 
  }
end

def MaterialResizerActions.resizeAllMats(maxSize)
  resizeMats(Sketchup.active_model.materials, maxSize)
end

def MaterialResizerActions.resizeMatsPrompt()
  resp = UI.inputbox(["Size"], [1024], "Max texture size")
  return if resp == false
  vali = nil
  begin
  vali = resp[0].to_i
  rescue
  end
  if vali == nil
    UI.messagebox("Invalid size")
    return
  end
  MaterialResizerActions.resizeAllMats(vali)
end

def MaterialResizerActions.showUI
  MaterialResizerUI.show
end

end
end
end