require 'json'
require 'Base64'

module Trimble
module MaterialResizer
class ModelChange < Sketchup::AppObserver
# The onActivateModel method is called when an open model is activated.
def onActivateModel(model)
  MaterialResizerUI.updateUI
end
# The onNewModel method is called when the application creates a new, empty model.
def onNewModel(model)
  MaterialResizerUI.updateUI
end
# The onOpenModel method is called when the application opens an existing model.
def onOpenModel(model)
  MaterialResizerUI.updateUI
end
end
class MaterialResizerUI
  @@matui = nil
  @dlg = nil
  @obs = nil
  def initialize
    @thumbMap = {}
    @activeModel = nil
    @obs = ModelChange.new
  end
  def show
    w = 450
    h = 700

    if @dlg == nil
        @dlg = UI::WebDialog.new("Material Resizer", true, "MaterialResizer", w, h, 0, 0, true)
        @dlg.min_height = h / 2
        @dlg.min_width = 350
        @dlg.add_action_callback("uiaction") { |dlg, params| uiAction(dlg, params.split(";")) }
        @dlg.set_file(Sketchup.find_support_file('MaterialResizerUI.html', 'Plugins/MaterialResizer/ui'))
        @dlg.set_on_close { onClose }
    end
    @dlg.show
    Sketchup.add_observer(@obs)
  end
  def MaterialResizerUI.show
    if (@@matui == nil)
      @@matui = MaterialResizerUI.new
    end
    @@matui.show
  end
  def MaterialResizerUI.updateUI
    @@matui.updateUI if @@matui != nil
  end
  def onClose
    @dlg = nil
    @@matui = nil
    Sketchup.remove_observer(@obs)
  end
  def uiAction(dlg, params)
    #puts params[0];
    case params[0]
    when "loaded"
        loaded()
    when "loadsettings"
        loadSettings()
    when "close"
        @dlg.close()
    when "resize"
      resizeMats(params[1].to_i, params.slice(2, params.length))
    end
  end
  def loaded
    @dlg.execute_script("loadComplete(" + MaterialResizer.isDebug?.to_s + ");")
    #UI.messagebox(SettingsMgr.servicePort.to_s)
  end
  def loadSettings()
    updateUI
  end
  
  def updateUI()
    # Reset the thumb map for each model
    if @activeModel == nil
      @activeModel = Sketchup.active_model.guid
    end
    if @activeModel != Sketchup.active_model.guid
      @thumbMap = {}
    end
    suMats = Sketchup.active_model.materials.select {|m| m.texture != nil}
    tmpFile = File.join(Trimble::MaterialResizer.tempDir, "matthumb.jpg")
    suMats.each {|m| 
      if not @thumbMap.key?(m.entityID)
        m.write_thumbnail(tmpFile, 30)
        File.open(tmpFile, "rb") {|f| @thumbMap[m.entityID] = Base64.encode64(f.read) }
      end
    }
    begin
      File.delete(tmpFile)
    rescue
    end
    allMats = suMats.map {|m| {"id" => m.entityID, "name" => m.name, "w" => m.texture.image_width, "h" => m.texture.image_height, "img" => @thumbMap[m.entityID]} }
    mats = {"all" => allMats}
    
    @dlg.execute_script("setSettings(" + JSON.dump(mats) + ");");
  end
  def resizeMats(maxSize, matIds)
    # Convert to dict for faster lookup
    matDict = {}
    matIds.each{|id| matDict[id.to_i] = true }
    mats = Sketchup.active_model.materials.select { |m| matDict.key?(m.entityID) }
    MaterialResizerActions.resizeMats(mats, maxSize)
    updateUI
  end
end
end
end